@@ -65,6 +65,7 @@ class Sf:
         self.debug: bool = False
         self.veeva_common:dict = None
         self.org_info:dict = None
+        self.sfdc_limits: dict = None
     
     def authenticate(self, sfUsername: Optional[str]=None, 
                                 sfPassword: Optional[str]=None, 
@@ -176,6 +177,9 @@ class Sf:
             self.record_count[x['name']] = x['count']
             self.record_count_caseinsensitive[x['name'].lower()] = x['count']
         
+        self.sfdc_limits = self.parse_sf_limits(self.sf_api_call('/services/data/'+self.api_version+'/limits'))
+        
+        
         if if_return:
             return {'sf':sf, 
                     'bulk':bulk, 
@@ -1404,7 +1408,25 @@ class Sf:
     ### ----------------------------------------------------------------------------------------------------
     ### Utility Functions
     ### ----------------------------------------------------------------------------------------------------
-    
+    def parse_sf_limits(self, sfdc_limits_result: dict, prefix=None) -> dict:
+        ## Recursively parse the limits result to find the limits that are not 0
+        result = {}
+        for key, item in sfdc_limits_result.items():
+            if set(['Max','Remaining']).issubset(set(item.keys())): 
+                if item['Max'] == 0:
+                    continue
+                else:
+                    result[key if prefix is None else prefix+' - '+key] = dict(zip(['Max','Remaining'],[item['Max'], item['Remaining']]))
+            
+            if len(set(item.keys()) - set(['Max','Remaining'])) > 0:
+                sub_item = item.copy()
+                if 'Max' in sub_item: 
+                    del sub_item['Max']
+                if 'Remaining' in sub_item: 
+                    del sub_item['Remaining']
+                result.update(self.parse_sf_limits(sub_item, prefix=key))
+        return result
+        
     def sf_api_call(self, action, parameters = {}, method = 'get', data = {}):
         """
         Helper function to make calls to Salesforce REST API.
